import React,{ useState, useEffect } from 'react';
import Students from './components/Students';
import Header from './components/Header'
import Form from './components/Form';

export const valueContext = React.createContext();

function App() {

  const [studentsData, setStudentsData] = useState([]);
  const [text, setText] = useState();
  const [mark, setMark] = useState();
  const [editId, setEdit] = useState();
  const [editMode, setEditMode] = useState(false);

  const fetchStudents = async () => {
    const response = await fetch('http://localhost:5000/students');
    const data = await response.json();
    return data;
  }

  useEffect(() => {
    const setStudents = async () => {
      const data = await fetchStudents()
      setStudentsData(data);
    }
    setStudents();
  }, [editMode])


  const addStudent = async (data) => {
    const response = await fetch('http://localhost:5000/students', { method: 'POST', headers: { 'content-type': 'application/json' }, body: JSON.stringify(data) });
    const datas = await response.json();
    setStudentsData([...studentsData, datas]);
  };

  const deleteStudent = async (id) => {
    if (window.confirm('Are you sure you want to Delete?') === true) {
      await fetch(`http://localhost:5000/students/${id}`, { method: 'DELETE' })
      setStudentsData(studentsData.filter((data) => data.id !== id))
    }
  }

  const updateStudent = async (id) => {
    let item = { text, mark }
    const response = await fetch(`http://localhost:5000/students/${id}`, {
      method: 'PUT',
      headers: {
        'Accept': 'application/json',
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(item)
    })
    const data = await response.json();
  }

  const handleEditChange = (id, text, mark) => {
    setEditMode(true);
    setEdit(id);
    setMark(mark);
    setText(text);
  };

  return (
    <div className="c-container">
      <valueContext.Provider value="Students Mark List
">
        <Header />
      </valueContext.Provider>
      <Form editId={editId} setEdit={setEdit} text={text} setText={setText} mark={mark} setMark={setMark} onAdd={addStudent} onEdit={updateStudent} editMode={editMode} />
      {studentsData.map((data, index) => (
        <Students key={data.id} index={index} id={data.id} marks={data.mark} onAdd={addStudent} onDelete={deleteStudent} handleEditChange={handleEditChange}>{data.text}</Students>
      ))}
    </div>
  );
}

export default App;
